import { Injectable } from '@nestjs/common';
import { InjectRepository } from '@nestjs/typeorm';
import { Label } from './entity/label.entity';
import { Repository } from 'typeorm';
import { LabelCategory } from './entity/category.entity';

@Injectable()
export class LabelService {
  constructor(
    @InjectRepository(Label)
    private readonly labelRepository: Repository<Label>,
    @InjectRepository(LabelCategory)
    private readonly labelCategoryRepository: Repository<LabelCategory>,
  ) {}

  async createLabelCategory({ name }: LabelCategory) {
    return await this.labelCategoryRepository.save({ name });
  }

  async createLabel({ categoryId: id, name }) {
    const category = await this.labelCategoryRepository.findOne({
      where: { id },
    });
    const label = new Label();
    label.name = name;
    label.category = category;
    return await this.labelRepository.save(label);
  }

  async updateLabel({ id, name }) {
    const label = await this.labelRepository.findOne({ where: { id } });
    label.name = name;
    return await this.labelRepository.save(label);
  }

  async findAllLabelCategory() {
    return await this.labelCategoryRepository.find({ relations: ['labels'] });
  }

  async deleteLabel({ id }) {
    return await this.labelRepository.delete({ id });
  }

  async updateLabelCategory({ name, id }) {
    return await this.labelCategoryRepository.update(id, { name });
  }
}
